@@ -2,7 +2,8 @@
 #    @Author-Email: justincpresley@gmail.com
 #    @Project: NDN State Vector Sync Protocol
 #    @Source-Code: https://github.com/justincpresley/ndn-python-svs
-#    @Pip-Library: https://pypi.org/project/ndn-svs/
+#    @Pip-Library: https://pypi.org/project/ndn-svs
+#    @Documentation: https://ndn-python-svs.readthedocs.io
 
 # API classes
 from .svs import SVSync
@@ -24,7 +25,6 @@ from .missing_data import MissingData
 from .security import SigningInfo, ValidatingInfo, SecurityOptions
 from .state_table import StateTable
 from .state_vector import StateVector
-from .storage import SVSyncStorage
 
 # Tool classes
 from .scheduler import AsyncScheduler
